AffiseInitProperties class

Constructors

AffiseInitProperties({required String? affiseAppId, required String? secretKey, bool isProduction = true, String? partParamName, String? partParamNameToken, String? appToken, String? domain, OnInitSuccessHandler? onInitSuccessHandler, OnInitErrorHandler? onInitErrorHandler, Map<AffiseConfig, dynamic> configValues = const {}, List<AffiseModules> disableModules = const []})

Properties

affiseAppId String?
getter/setter pair
appToken String?
getter/setter pair
autoCatchingClickEvents List<AutoCatchingType>?
getter/setter pair
configValues Map<AffiseConfig, dynamic>
getter/setter pair
disableModules List<AffiseModules>
getter/setter pair
domain String?
getter/setter pair
enabledMetrics bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isProduction bool
getter/setter pair
onInitErrorHandler OnInitErrorHandler?
getter/setter pair
onInitSuccessHandler OnInitSuccessHandler?
getter/setter pair
partParamName String?
getter/setter pair
partParamNameToken String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String?
getter/setter pair
toMap Map<String, dynamic>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited