AffiseDebug class abstract

Implemented types

Constructors

AffiseDebug(AffiseNative _native)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

network(DebugOnNetworkCallback callback) → void
Debug network request/response
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(DebugOnValidateCallback callback) → void
Debug validate
override
version() String
Debug get version of flutter library
override
versionNative() Future<String>
Debug get version of native library Android/iOS
override

Operators

operator ==(Object other) bool
The equality operator.
inherited