AffiseDebugApi class abstract

Implementers

Constructors

AffiseDebugApi()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

network(DebugOnNetworkCallback callback) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(DebugOnValidateCallback callback) → void
version() String
versionNative() Future<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited