EventName enum

Inheritance
Available extensions

Values

ACHIEVE_LEVEL → const EventName
ADD_PAYMENT_INFO → const EventName
ADD_TO_CART → const EventName
ADD_TO_WISHLIST → const EventName
AD_REVENUE → const EventName
CLICK_ADV → const EventName
COMPLETE_REGISTRATION → const EventName
COMPLETE_STREAM → const EventName
COMPLETE_TRIAL → const EventName
COMPLETE_TUTORIAL → const EventName
CONTACT → const EventName
CONTENT_ITEMS_VIEW → const EventName
CUSTOM_ID_01 → const EventName
CUSTOM_ID_02 → const EventName
CUSTOM_ID_03 → const EventName
CUSTOM_ID_04 → const EventName
CUSTOM_ID_05 → const EventName
CUSTOM_ID_06 → const EventName
CUSTOM_ID_07 → const EventName
CUSTOM_ID_08 → const EventName
CUSTOM_ID_09 → const EventName
CUSTOM_ID_10 → const EventName
CUSTOMIZE_PRODUCT → const EventName
DEEP_LINKED → const EventName
FIND_LOCATION → const EventName
INITIATE_CHECKOUT → const EventName
INITIATE_PURCHASE → const EventName
INITIATE_STREAM → const EventName
INVITE → const EventName
LAST_ATTRIBUTED_TOUCH → const EventName
LEAD → const EventName
LIST_VIEW → const EventName
LOGIN → const EventName
OPENED_FROM_PUSH_NOTIFICATION → const EventName
ORDER → const EventName
ORDER_ITEM_ADDED → const EventName
ORDER_ITEM_REMOVE → const EventName
ORDER_CANCEL → const EventName
ORDER_RETURN_REQUEST → const EventName
ORDER_RETURN_REQUEST_CANCEL → const EventName
PURCHASE → const EventName
RATE → const EventName
RE_ENGAGE → const EventName
RESERVE → const EventName
SALES → const EventName
SCHEDULE → const EventName
SHARE → const EventName
SPEND_CREDITS → const EventName
START_REGISTRATION → const EventName
START_TRIAL → const EventName
START_TUTORIAL → const EventName
SUBMIT_APPLICATION → const EventName
SUBSCRIBE → const EventName
TRAVEL_BOOKING → const EventName
UNLOCK_ACHIEVEMENT → const EventName
UNSUBSCRIBE → const EventName
UPDATE → const EventName
VIEW_ADV → const EventName
VIEW_CART → const EventName
VIEW_CONTENT → const EventName
VIEW_ITEM → const EventName
VIEW_ITEMS → const EventName

Properties

eventName String

Available on EventName, provided by the EventNameExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAffiseEventProperty(AffiseProperty property) String

Available on EventName, provided by the EventNameExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EventName>
A constant List of the values in this enum, in order of their declaration.