PredefinedFloat enum

Type of predefined parameters contains Float value

@property value the key of parameter

Inheritance
Available extensions

Values

PREFERRED_PRICE_RANGE → const PredefinedFloat
PRICE → const PredefinedFloat
REVENUE → const PredefinedFloat
LAT → const PredefinedFloat
LONG → const PredefinedFloat

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on PredefinedFloat, provided by the PredefinedFloatExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PredefinedFloat>
A constant List of the values in this enum, in order of their declaration.