PredefinedLong enum

Inheritance
Available extensions

Values

AMOUNT → const PredefinedLong
DATE_A → const PredefinedLong
DATE_B → const PredefinedLong
DEPARTING_ARRIVAL_DATE → const PredefinedLong
DEPARTING_DEPARTURE_DATE → const PredefinedLong
HOTEL_SCORE → const PredefinedLong
LEVEL → const PredefinedLong
MAX_RATING_VALUE → const PredefinedLong
NUM_ADULTS → const PredefinedLong
NUM_CHILDREN → const PredefinedLong
NUM_INFANTS → const PredefinedLong
PREFERRED_NUM_STOPS → const PredefinedLong
PREFERRED_STAR_RATINGS → const PredefinedLong
QUANTITY → const PredefinedLong
RATING_VALUE → const PredefinedLong
RETURNING_ARRIVAL_DATE → const PredefinedLong
RETURNING_DEPARTURE_DATE → const PredefinedLong
SCORE → const PredefinedLong
TRAVEL_START → const PredefinedLong
TRAVEL_END → const PredefinedLong
USER_SCORE → const PredefinedLong
EVENT_START → const PredefinedLong
EVENT_END → const PredefinedLong

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on PredefinedLong, provided by the PredefinedLongExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PredefinedLong>
A constant List of the values in this enum, in order of their declaration.