PredefinedString enum

Inheritance
Available extensions

Values

ADREV_AD_TYPE → const PredefinedString
CITY → const PredefinedString
COUNTRY → const PredefinedString
REGION → const PredefinedString
CLASS → const PredefinedString
CONTENT_ID → const PredefinedString
CONTENT_TYPE → const PredefinedString
CURRENCY → const PredefinedString
CUSTOMER_USER_ID → const PredefinedString
DESCRIPTION → const PredefinedString
DESTINATION_A → const PredefinedString
DESTINATION_B → const PredefinedString
DESTINATION_LIST → const PredefinedString
ORDER_ID → const PredefinedString
PAYMENT_INFO_AVAILABLE → const PredefinedString
PREFERRED_NEIGHBORHOODS → const PredefinedString
PURCHASE_CURRENCY → const PredefinedString
RECEIPT_ID → const PredefinedString
REGISTRATION_METHOD → const PredefinedString
SEARCH_STRING → const PredefinedString
SUBSCRIPTION_ID → const PredefinedString
SUCCESS → const PredefinedString
SUGGESTED_DESTINATIONS → const PredefinedString
SUGGESTED_HOTELS → const PredefinedString
VALIDATED → const PredefinedString
ACHIEVEMENT_ID → const PredefinedString
COUPON_CODE → const PredefinedString
CUSTOMER_SEGMENT → const PredefinedString
NEW_VERSION → const PredefinedString
OLD_VERSION → const PredefinedString
PARAM_01 → const PredefinedString
PARAM_02 → const PredefinedString
PARAM_03 → const PredefinedString
PARAM_04 → const PredefinedString
PARAM_05 → const PredefinedString
PARAM_06 → const PredefinedString
PARAM_07 → const PredefinedString
PARAM_08 → const PredefinedString
PARAM_09 → const PredefinedString
PARAM_10 → const PredefinedString
REVIEW_TEXT → const PredefinedString
TUTORIAL_ID → const PredefinedString
VIRTUAL_CURRENCY_NAME → const PredefinedString
STATUS → const PredefinedString
BRAND → const PredefinedString
BRICK → const PredefinedString
CATALOGUE_ID → const PredefinedString
CHANNEL_TYPE → const PredefinedString
CUSTOMER_TYPE → const PredefinedString
SEGMENT → const PredefinedString
UTM_CAMPAIGN → const PredefinedString
UTM_MEDIUM → const PredefinedString
UTM_SOURCE → const PredefinedString
VERTICAL → const PredefinedString
VOUCHER_CODE → const PredefinedString
CLICK_ID → const PredefinedString
CAMPAIGN_ID → const PredefinedString
EVENT_NAME → const PredefinedString
PID → const PredefinedString
PRODUCT_ID → const PredefinedString
CONVERSION_ID → const PredefinedString
CONTENT_NAME → const PredefinedString
PRODUCT_NAME → const PredefinedString
SOURCE → const PredefinedString
NETWORK → const PredefinedString
UNIT → const PredefinedString
PLACEMENT → const PredefinedString

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on PredefinedString, provided by the PredefinedStringExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PredefinedString>
A constant List of the values in this enum, in order of their declaration.