AffiseResult<S> class

Constructors

AffiseResult()
const

Properties

asFailure String
no setter
asSuccess → S
no setter
hashCode int
The hash code for this object.
no setterinherited
isFailure bool
no setter
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

failure<T>(String error) AffiseResult<T>
success<T>(T value) AffiseResult<T>