AffiseModuleAppsFlyerApi class abstract

Inheritance
Implementers

Constructors

AffiseModuleAppsFlyerApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasModule() Future<bool>
inherited
logEvent(String eventName, Map<String, dynamic> eventValues) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited