AffiseAndroid class abstract

Implemented types

Constructors

AffiseAndroid(AffiseNative _native)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

crashApplication() → void
override
forget(String userData) → void
Erases all user data from mobile and sends GDPREvent userData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited