AffiseApiMethod enum

Inheritance
Available extensions

Values

INIT → const AffiseApiMethod
SEND_EVENT → const AffiseApiMethod
SEND_EVENT_NOW → const AffiseApiMethod
ADD_PUSH_TOKEN → const AffiseApiMethod
REGISTER_WEB_VIEW → const AffiseApiMethod
UNREGISTER_WEB_VIEW → const AffiseApiMethod
SET_SECRET_KEY → const AffiseApiMethod
SET_AUTO_CATCHING_TYPES → const AffiseApiMethod
SET_OFFLINE_MODE_ENABLED → const AffiseApiMethod
IS_OFFLINE_MODE_ENABLED → const AffiseApiMethod
SET_BACKGROUND_TRACKING_ENABLED → const AffiseApiMethod
IS_BACKGROUND_TRACKING_ENABLED → const AffiseApiMethod
SET_TRACKING_ENABLED → const AffiseApiMethod
IS_TRACKING_ENABLED → const AffiseApiMethod
FORGET → const AffiseApiMethod
SET_ENABLED_METRICS → const AffiseApiMethod
CRASH_APPLICATION → const AffiseApiMethod
GET_RANDOM_USER_ID → const AffiseApiMethod
GET_RANDOM_DEVICE_ID → const AffiseApiMethod
GET_PROVIDERS → const AffiseApiMethod
IS_FIRST_RUN → const AffiseApiMethod
ON_INIT_SUCCESS_HANDLER → const AffiseApiMethod
ON_INIT_ERROR_HANDLER → const AffiseApiMethod
GET_REFERRER_URL_CALLBACK → const AffiseApiMethod
GET_REFERRER_URL_VALUE_CALLBACK → const AffiseApiMethod
SKAD_REGISTER_ERROR_CALLBACK → const AffiseApiMethod
SKAD_POSTBACK_ERROR_CALLBACK → const AffiseApiMethod
DEBUG_VALIDATE_CALLBACK → const AffiseApiMethod
DEBUG_NETWORK_CALLBACK → const AffiseApiMethod
DEBUG_VERSION_NATIVE → const AffiseApiMethod
GET_MODULES_INSTALLED → const AffiseApiMethod

///////////////////////////////////// /////////////////////////////////////

GET_STATUS_CALLBACK → const AffiseApiMethod
MODULE_APPSFLYER_LOG_EVENT → const AffiseApiMethod
MODULE_SUBS_FETCH_PRODUCTS_CALLBACK → const AffiseApiMethod
MODULE_SUBS_PURCHASE_CALLBACK → const AffiseApiMethod
MODULE_TIKTOK_EVENT → const AffiseApiMethod
MODULE_ADVERTISING_START → const AffiseApiMethod

///////////////////////////////////// /////////////////////////////////////

Properties

apiName String

Available on AffiseApiMethod, provided by the AffiseApiMethodExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AffiseApiMethod>
A constant List of the values in this enum, in order of their declaration.