DataName class

Constructors

DataName()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

BODY → const String
COARSE_VALUE → const String
CODE → const String
CURRENCY_CODE → const String
DESCRIPTION → const String
ERROR → const String
EVENT_ID → const String
EVENT_NAME → const String
EVENT_VALUES → const String
FAILED → const String
FINE_VALUE → const String
FORMATTED_PRICE → const String
HEADERS → const String
HOST → const String
INVALID_IDS → const String
MESSAGE → const String
METHOD → const String
NUMBER_OF_UNITS → const String
OFFER_ID → const String
OFFER_TOKEN → const String
ORDER_ID → const String
ORIGINAL_ORDER_ID → const String
PARAMETERS → const String
PATH → const String
PRICE → const String
PRODUCT → const String
PRODUCT_DETAILS → const String
PRODUCT_ID → const String
PRODUCT_TYPE → const String
PRODUCTS → const String
PURCHASE → const String
PUSH_TOKEN → const String
PUSH_TOKEN_SERVICE → const String
REQUEST → const String
RESPONSE → const String
SCHEME → const String
SUBSCRIPTION → const String
SUCCESS → const String
TIME_UNIT → const String
TITLE → const String
TYPE → const String
URL → const String
VALUE → const String