NativeBase class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apiCall<T>(String apiName, [Object? data])
→ Future<T?>
-
inherited
-
apiCallback(String apiName, dynamic arguments)
→ dynamic
-
override
-
apiStream(String apiName, dynamic arguments)
→ dynamic
-
override
-
handleCallback(AffiseApiMethod api, dynamic callback, dynamic data, String? tag)
→ dynamic
-
-
handleStream(AffiseApiMethod api, dynamic callback, dynamic data)
→ void
-
-
native<T>(AffiseApiMethod api, [dynamic data])
→ Future<T?>
-
-
nativeCallback(AffiseApiMethod api, dynamic callback, [dynamic data])
→ void
-
-
nativeCallbackGroup(AffiseApiMethod api, Map<String, dynamic> callbackGroup, [dynamic data])
→ void
-
-
nativeCallbackOnce(AffiseApiMethod api, dynamic callback, [dynamic data])
→ void
-
-
nativeCallbackOnly(AffiseApiMethod api, dynamic callback)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
removeApiCallback(AffiseApiMethod api)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited