NativeBasePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NativeBasePlatform
Implementers

Constructors

NativeBasePlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apiCall<T>(String apiName, [Object? data]) Future<T?>
apiCallback(String apiName, dynamic arguments) → dynamic
apiStream(String apiName, dynamic arguments) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NativeBasePlatform
Platform-specific plugins should set this with their own platform-specific class that extends NativeBasePlatform when they register themselves.
getter/setter pair