Parameters class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- AFFISE_EVENT_CATEGORY → const String
- AFFISE_EVENT_DATA → const String
- AFFISE_EVENT_FIRST_FOR_USER → const String
- AFFISE_EVENT_ID → const String
- AFFISE_EVENT_NAME → const String
- AFFISE_EVENT_TIMESTAMP → const String
- AFFISE_EVENT_USER_DATA → const String
- AFFISE_PARAMETERS → const String