AffiseModules enum
- Inheritance
- Available extensions
Values
- ADSERVICE → const AffiseModules
- ADVERTISING → const AffiseModules
- ANDROIDID → const AffiseModules
- APPSFLYER → const AffiseModules
- LINK → const AffiseModules
- META → const AffiseModules
- NETWORK → const AffiseModules
- PERSISTENT → const AffiseModules
- PHONE → const AffiseModules
- STATUS → const AffiseModules
- SUBSCRIPTION → const AffiseModules
- RUSTORE → const AffiseModules
- HUAWEI → const AffiseModules
- TIKTOK → const AffiseModules
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Available on AffiseModules, provided by the AffiseModulesExt extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String? value) → AffiseModules?
Constants
-
values
→ const List<
AffiseModules> - A constant List of the values in this enum, in order of their declaration.