AffiseAttributionModules class abstract
- Implemented types
Constructors
- AffiseAttributionModules(AffiseNative _native)
Properties
- advertising → AffiseModuleAdvertisingApi
-
final
- appsFlyer → AffiseModuleAppsFlyerApi
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → AffiseModuleLinkApi
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription → AffiseModuleSubscriptionApi
-
final
- tikTok → AffiseModuleTikTokApi
-
final
Methods
-
getModulesInstalled(
) → Future< List< AffiseModules> > -
Get installed modules
override
-
getStatus(
AffiseModules module, OnKeyValueCallback callback) → void -
Get module status
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited