AffiseAttributionModulesApi class abstract
- Implementers
Constructors
Properties
- advertising → AffiseModuleAdvertisingApi
-
no setter
- appsFlyer → AffiseModuleAppsFlyerApi
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → AffiseModuleLinkApi
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription → AffiseModuleSubscriptionApi
-
no setter
- tikTok → AffiseModuleTikTokApi
-
no setter
Methods
-
getModulesInstalled(
) → Future< List< AffiseModules> > -
getStatus(
AffiseModules module, OnKeyValueCallback callback) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited