AffiseModuleSubscriptionApi class abstract
- Inheritance
-
- Object
- AffiseHasModule
- AffiseModuleSubscriptionApi
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchProducts(
List< String> ids, AffiseResultCallback<AffiseProductsResult> callback) → void - Module subscription fetchProducts
-
hasModule(
) → Future< bool> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purchase(
AffiseProduct product, AffiseProductType type, AffiseResultCallback< AffisePurchasedInfo> callback) → void - Module subscription purchase
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited