DataMapper class

Constructors

DataMapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPrice(AffiseProductPrice? price) Map<String, dynamic>?
fromProduct(AffiseProduct product) Map<String, dynamic>
fromSubscription(AffiseProductSubscriptionDetail? subscription) Map<String, dynamic>?
toAffiseKeyValueList({dynamic from}) List<AffiseKeyValue>
toAffiseProductsResult(dynamic from) AffiseProductsResult?
toAffisePurchasedInfo(dynamic from) AffisePurchasedInfo?
toDeeplinkValue({dynamic from}) DeeplinkValue
toNonNullString({dynamic from}) String
toPrice(dynamic from) AffiseProductPrice?
toProduct(dynamic from) AffiseProduct?
toProductsList(dynamic from) List<AffiseProduct>
toResultAffiseProductsResult({required dynamic from}) AffiseResult<AffiseProductsResult>
toResultAffisePurchasedInfo({required dynamic from}) AffiseResult<AffisePurchasedInfo>
toSubscriptionDetail(dynamic from) AffiseProductSubscriptionDetail?