ReferrerKey enum
- Inheritance
- Available extensions
Values
- AD_ID → const ReferrerKey
- CAMPAIGN_ID → const ReferrerKey
- CLICK_ID → const ReferrerKey
- AFFISE_AD → const ReferrerKey
- AFFISE_AD_ID → const ReferrerKey
- AFFISE_AD_TYPE → const ReferrerKey
- AFFISE_ADSET → const ReferrerKey
- AFFISE_ADSET_ID → const ReferrerKey
- AFFISE_AFFC_ID → const ReferrerKey
- AFFISE_CHANNEL → const ReferrerKey
- AFFISE_CLICK_LOOK_BACK → const ReferrerKey
- AFFISE_COST_CURRENCY → const ReferrerKey
- AFFISE_COST_MODEL → const ReferrerKey
- AFFISE_COST_VALUE → const ReferrerKey
- AFFISE_DEEPLINK → const ReferrerKey
- AFFISE_KEYWORDS → const ReferrerKey
- AFFISE_MEDIA_TYPE → const ReferrerKey
- AFFISE_MODEL → const ReferrerKey
- AFFISE_OS → const ReferrerKey
- AFFISE_PARTNER → const ReferrerKey
- AFFISE_REF → const ReferrerKey
- AFFISE_SITE_ID → const ReferrerKey
- AFFISE_SUB_SITE_ID → const ReferrerKey
- AFFC → const ReferrerKey
- PID → const ReferrerKey
- SUB_1 → const ReferrerKey
- SUB_2 → const ReferrerKey
- SUB_3 → const ReferrerKey
- SUB_4 → const ReferrerKey
- SUB_5 → const ReferrerKey
- AFFISE_SUB_1 → const ReferrerKey
- AFFISE_SUB_2 → const ReferrerKey
- AFFISE_SUB_3 → const ReferrerKey
- AFFISE_SUB_4 → const ReferrerKey
- AFFISE_SUB_5 → const ReferrerKey
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Available on ReferrerKey, provided by the ReferrerKeyValue extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ReferrerKey> - A constant List of the values in this enum, in order of their declaration.